@@ -30,7 +30,6 @@ def _implement_cli(
         "url": url,
         "profile_name": profile_name,
     }
-    client_config._x_source = "PYTHON-CLI"  # pylint: disable=protected-access
 
     if debug:
         logging.basicConfig(level=logging.DEBUG)
@@ -43,29 +42,36 @@ def _get_config_filepath() -> str:
         The path of the config file.
 
     """
-    home = "USERPROFILE" if os.name == "nt" else "HOME"
+    home = "USERPROFILE" if is_win() else "HOME"
     return os.path.join(os.environ[home], ".gasconfig")
 
 
-def _read_profile(profile_name: str) -> Tuple[str, str]:
+def is_win() -> bool:
+    """Determine whether the current system is Windows.
+
+    Returns:
+        Whether the current system is Windows.
+
+    """
+    return sys.platform.startswith("win")
+
+
+def read_profile(profile_name: str, config_parser: ConfigParser) -> Tuple[str, str]:
     """Read accessKey and URL from the config file.
 
     Arguments:
         profile_name: The environment to login.
+        config_parser: The config parser read from the config file.
 
     Returns:
         A tuple containing the accessKey and the url of profile_name read from the config file.
 
     """
-    config_filepath = _get_config_filepath()
-    if not os.path.exists(config_filepath):
+    if not config_parser.has_option("profiles", profile_name):
         error(
-            f"{config_filepath} not exist"
-            "\n\nPlease use 'gas config <accessKey>' to create config file"
+            f"{profile_name} does not exist"
+            f"\n\nPlease use 'gas -p {profile_name} auth [accessKey]' to create profile"
         )
-
-    update_config()
-    config_parser = read_config(config_filepath)
     values = config_parser["profiles"][profile_name].split("\n")
     if len(values) == 2:
         return values[1], ""
@@ -86,8 +92,11 @@ def get_gas(access_key: str, url: str, profile_name: str) -> GAS:
         Gas client logged in with accessKey and URL.
 
     """
+    update_config()
+    config_parser = read_config()
+    _set_request_config(config_parser)
     if not access_key and not url:
-        access_key, url = _read_profile(profile_name)
+        access_key, url = read_profile(profile_name, config_parser)
 
     if not access_key:
         error("AccessKey should be appointed")
@@ -139,7 +148,7 @@ def get_dataset_client(gas: GAS, info: TBRN, is_fusion: Optional[bool] = None) -
     return dataset_client
 
 
-def edit_input(hint: str) -> Tuple[str, str]:
+def _edit_input(hint: str) -> Tuple[str, str]:
     """Edit information input from the editor.
 
     Arguments:
@@ -152,7 +161,7 @@ def edit_input(hint: str) -> Tuple[str, str]:
     config_parser = read_config()
 
     editor = config_parser["config"].get("editor") if config_parser.has_section("config") else None
-    input_info = click.edit(hint, editor=editor)
+    input_info = click.edit(hint, editor=editor, require_save=False)
     return _clean_up(input_info)
 
 
@@ -255,6 +264,7 @@ def read_config(config_filepath: Optional[str] = None) -> ConfigParser:
     """
     if not config_filepath:
         config_filepath = _get_config_filepath()
+
     config_parser = ConfigParser(dict_type=OrderedDict)
     config_parser.read(config_filepath)
     return config_parser
@@ -307,3 +317,59 @@ def shorten(origin: str) -> str:
 
     """
     return origin[:7]
+
+
+def format_hint(title: str, description: str, original_hint: str) -> str:
+    """Generate complete hint message.
+
+    Arguments:
+        title: The title of the draft to edit or commit.
+        description: The description of the draft to edit or commit.
+        original_hint: The original hint message.
+
+    Returns:
+        The complete hint message.
+
+    """
+    hint: Tuple[str, ...] = (title,)
+    if description:
+        hint += ("", description)
+    hint += (original_hint,)
+    return "\n".join(hint)
+
+
+def edit_message(message: Tuple[str, ...], hint_message: str) -> Tuple[str, str]:
+    """Edit draft information.
+
+    Arguments:
+        message: The message given in the CLI.
+        hint_message: The hint message to show on the pop-up editor.
+
+    Returns:
+        The extracted title and the description.
+
+    """
+    if message:
+        title, description = message[0], "\n".join(message[1:])
+    else:
+        title, description = _edit_input(hint_message)
+
+    return title, description
+
+
+def _set_request_config(config_parser: ConfigParser) -> None:
+    """Configure request related parameters.
+
+    Arguments:
+        config_parser: The config parser read from the config file.
+
+    """
+    client_config._x_source = "PYTHON-CLI"  # pylint: disable=protected-access
+    if config_parser.has_section("config"):
+        config_section = config_parser["config"]
+        if "timeout" in config_section:
+            client_config.timeout = config_section.getint("timeout")
+        if "is_internal" in config_section:
+            client_config.is_internal = config_section.getboolean("is_internal")
+        if "max_retries" in config_section:
+            client_config.max_retries = config_section.getint("max_retries")
