@@ -6,14 +6,25 @@
 """Label related classes."""
 
 from .attributes import AttributeInfo, Items
-from .basic import LabelType
-from .catalog import Catalog, Subcatalogs
+from .catalog import Catalog
 from .label import Label
 from .label_box import Box2DSubcatalog, Box3DSubcatalog, LabeledBox2D, LabeledBox3D
 from .label_classification import Classification, ClassificationSubcatalog
 from .label_keypoints import Keypoints2DSubcatalog, LabeledKeypoints2D
-from .label_polygon import LabeledPolygon, PolygonSubcatalog
-from .label_polyline import LabeledPolyline2D, Polyline2DSubcatalog
+from .label_polygon import (
+    LabeledMultiPolygon,
+    LabeledPolygon,
+    LabeledRLE,
+    MultiPolygonSubcatalog,
+    PolygonSubcatalog,
+    RLESubcatalog,
+)
+from .label_polyline import (
+    LabeledMultiPolyline2D,
+    LabeledPolyline2D,
+    MultiPolyline2DSubcatalog,
+    Polyline2DSubcatalog,
+)
 from .label_sentence import LabeledSentence, SentenceSubcatalog, Word
 from .supports import CategoryInfo, KeypointsInfo
 
@@ -25,20 +36,24 @@ __all__ = [
     "CategoryInfo",
     "Classification",
     "ClassificationSubcatalog",
-    "KeypointsInfo",
+    "Items",
     "Keypoints2DSubcatalog",
+    "KeypointsInfo",
     "Label",
-    "LabelType",
     "LabeledBox2D",
     "LabeledBox3D",
     "LabeledKeypoints2D",
+    "LabeledMultiPolygon",
+    "LabeledMultiPolyline2D",
     "LabeledPolygon",
     "LabeledPolyline2D",
+    "LabeledRLE",
     "LabeledSentence",
-    "Items",
+    "MultiPolygonSubcatalog",
+    "MultiPolyline2DSubcatalog",
     "PolygonSubcatalog",
     "Polyline2DSubcatalog",
+    "RLESubcatalog",
     "SentenceSubcatalog",
-    "Subcatalogs",
     "Word",
 ]
