@@ -13,30 +13,32 @@ Different label types correspond to different label classes classes.
 .. table:: label classes
    :widths: auto
 
-   ============================================================= ===================================
-   label classes                                                 explaination
-   ============================================================= ===================================
-   :class:`~tensorbay.label.label_classification.Classification` classification type of label
-   :class:`~tensorbay.label.label_box.LabeledBox2D`              2D bounding box type of label
-   :class:`~tensorbay.label.label_box.LabeledBox3D`              3D bounding box type of label
-   :class:`~tensorbay.label.label_polygon.LabeledPolygon2D`      2D polygon type of label
-   :class:`~tensorbay.label.label_polyline.LabeledPolyline2D`    2D polyline type of label
-   :class:`~tensorbay.label.label_keypoints.LabeledKeypoints2D`  2D keypoints type of label
-   :class:`~tensorbay.label.label_sentence.LabeledSentence`      transcripted sentence type of label
-   ============================================================= ===================================
+   ================================ ===================================
+   label classes                    explaination
+   ================================ ===================================
+   :class:`.Classification`         classification type of label
+   :class:`.LabeledBox2D`           2D bounding box type of label
+   :class:`.LabeledBox3D`           3D bounding box type of label
+   :class:`.LabeledPolygon`         polygon type of label
+   :class:`.LabeledMultiPolygon`    polygon lists type of label
+   :class:`.LabeledRLE`             rle mask type of label
+   :class:`.LabeledPolyline2D`      2D polyline type of label
+   :class:`.LabeledMultiPolyline2D` 2D polyline lists type of label
+   :class:`.LabeledKeypoints2D`     2D keypoints type of label
+   :class:`.LabeledSentence`        transcripted sentence type of label
+   ================================ ===================================
 
 """
 
 from functools import partial
-from typing import Any, Dict, List, Type, TypeVar
+from typing import Any, Dict, Iterator, List, Type, TypeVar
 
 from ..utility import AttrsMixin, ReprMixin, ReprType, attr, common_loads, upper
-from .basic import LabelType
 from .label_box import LabeledBox2D, LabeledBox3D
 from .label_classification import Classification
 from .label_keypoints import LabeledKeypoints2D
-from .label_polygon import LabeledPolygon2D
-from .label_polyline import LabeledPolyline2D
+from .label_polygon import LabeledMultiPolygon, LabeledPolygon, LabeledRLE
+from .label_polyline import LabeledMultiPolyline2D, LabeledPolyline2D
 from .label_sentence import LabeledSentence
 
 _ERROR_MESSAGE = "The '{attr_name}' label is not provided in this data"
@@ -65,22 +67,25 @@ class Label(ReprMixin, AttrsMixin):
     _T = TypeVar("_T", bound="Label")
 
     _repr_type = ReprType.INSTANCE
-    _repr_attrs = tuple(label_type.value for label_type in LabelType)
     _repr_maxlevel = 2
 
     classification: Classification = _attr()
     box2d: List[LabeledBox2D] = _attr()
     box3d: List[LabeledBox3D] = _attr()
-    polygon2d: List[LabeledPolygon2D] = _attr()
+    polygon: List[LabeledPolygon] = _attr()
     polyline2d: List[LabeledPolyline2D] = _attr()
+    multi_polyline2d: List[LabeledMultiPolyline2D] = _attr()
+    rle: List[LabeledRLE] = _attr()
     keypoints2d: List[LabeledKeypoints2D] = _attr()
+    multi_polygon: List[LabeledMultiPolygon] = _attr()
     sentence: List[LabeledSentence] = _attr()
 
     def __bool__(self) -> bool:
-        for label_type in LabelType:
-            if hasattr(self, label_type.value):
-                return True
-        return False
+        return any(hasattr(self, key) for key in self._attrs_fields)
+
+    @property
+    def _repr_attrs(self) -> Iterator[str]:  # type: ignore[override]
+        yield from self._attrs_fields
 
     @classmethod
     def loads(cls: Type[_T], contents: Dict[str, Any]) -> _T:
