@@ -8,6 +8,7 @@
 import os
 
 from ...dataset import Data, Dataset
+from ...exception import ModuleImportError
 from ...label import Classification
 
 DATASET_NAME_17 = "Flower17"
@@ -36,18 +37,24 @@ def Flower17(path: str) -> Dataset:
     Arguments:
         path: The root directory of the dataset.
 
+    Raises:
+        ModuleImportError: When the module "scipy" can not be found.
+
     Returns:
         Loaded :class:`~tensorbay.dataset.dataset.Dataset` instance.
 
     """
-    from scipy.io import loadmat  # pylint: disable=import-outside-toplevel
+    try:
+        from scipy.io import loadmat  # pylint: disable=import-outside-toplevel
+    except ModuleNotFoundError as error:
+        raise ModuleImportError(error.name) from error  # type: ignore[arg-type]
 
     root_path = os.path.abspath(os.path.expanduser(path))
     segment_info = loadmat(os.path.join(root_path, "datasplits.mat"))
 
     dataset = Dataset(DATASET_NAME_17)
     dataset.load_catalog(os.path.join(os.path.dirname(__file__), "catalog_17.json"))
-    categories = list(dataset.catalog.classification.categories)
+    index_to_category = dataset.catalog.classification.get_index_to_category()
     for key, value in _SEGMENT_NAMES_17.items():
         segment = dataset.create_segment(key)
         segment_info[value][0].sort()
@@ -55,7 +62,9 @@ def Flower17(path: str) -> Dataset:
             data = Data(os.path.join(root_path, "jpg", f"image_{index:04d}.jpg"))
 
             # There are 80 images for each category
-            data.label.classification = Classification(category=categories[(index - 1) // 80])
+            data.label.classification = Classification(
+                category=index_to_category[(index - 1) // 80]
+            )
             segment.append(data)
 
     return dataset
@@ -78,11 +87,17 @@ def Flower102(path: str) -> Dataset:
     Arguments:
         path: The root directory of the dataset.
 
+    Raises:
+        ModuleImportError: When the module "scipy" can not be found.
+
     Returns:
         Loaded :class:`~tensorbay.dataset.dataset.Dataset` instance.
 
     """
-    from scipy.io import loadmat  # pylint: disable=import-outside-toplevel
+    try:
+        from scipy.io import loadmat  # pylint: disable=import-outside-toplevel
+    except ModuleNotFoundError as error:
+        raise ModuleImportError(error.name) from error  # type: ignore[arg-type]
 
     root_path = os.path.abspath(os.path.expanduser(path))
     labels = loadmat(os.path.join(root_path, "imagelabels.mat"))["labels"][0]
@@ -90,12 +105,14 @@ def Flower102(path: str) -> Dataset:
 
     dataset = Dataset(DATASET_NAME_102)
     dataset.load_catalog(os.path.join(os.path.dirname(__file__), "catalog_102.json"))
-    categories = list(dataset.catalog.classification.categories)
+    index_to_category = dataset.catalog.classification.get_index_to_category()
     for key, value in _SEGMENT_NAMES_102.items():
         segment = dataset.create_segment(key)
         segment_info[value][0].sort()
         for index in segment_info[value][0]:
             data = Data(os.path.join(root_path, "jpg", f"image_{index:05d}.jpg"))
-            data.label.classification = Classification(categories[int(labels[index - 1]) - 1])
+            data.label.classification = Classification(
+                index_to_category[int(labels[index - 1]) - 1]
+            )
             segment.append(data)
     return dataset
