@@ -5,15 +5,19 @@
 
 """OpenDataset dataloader collections."""
 
+from .AADB import AADB
 from .AnimalPose import AnimalPose5, AnimalPose7
 from .AnimalsWithAttributes2 import AnimalsWithAttributes2
 from .BDD100K import BDD100K
 from .BioIDFace import BioIDFace
 from .BSTLD import BSTLD
+from .CACD import CACD
 from .CADC import CADC
 from .CarConnection import CarConnection
+from .CCPD import CCPD, CCPDGreen
 from .CoinImage import CoinImage
 from .CompCars import CompCars
+from .COVID_CT import COVID_CT
 from .COVIDChestXRay import COVIDChestXRay
 from .DeepRoute import DeepRoute
 from .DogsVsCats import DogsVsCats
@@ -40,18 +44,25 @@ from .RP2K import RP2K
 from .THCHS30 import THCHS30
 from .THUCNews import THUCNews
 from .TLR import TLR
+from .UAVDT import UAVDT
+from .VOC2012ActionClassification import VOC2012ActionClassification
+from .VOC2012Detection import VOC2012Detection
 from .WIDER_FACE import WIDER_FACE
 
 __all__ = [
     "nuScenes",
+    "AADB",
     "AnimalPose5",
     "AnimalPose7",
     "AnimalsWithAttributes2",
     "BioIDFace",
     "BDD100K",
     "BSTLD",
+    "CACD",
     "CADC",
     "CarConnection",
+    "CCPD",
+    "CCPDGreen",
     "CoinImage",
     "COVIDChestXRay",
     "CompCars",
@@ -82,5 +93,9 @@ __all__ = [
     "THCHS30",
     "THUCNews",
     "TLR",
+    "UAVDT",
     "WIDER_FACE",
+    "COVID_CT",
+    "VOC2012Detection",
+    "VOC2012ActionClassification",
 ]
