@@ -3,7 +3,7 @@
 # Copyright 2021 Graviti. Licensed under MIT License.
 #
 
-"""TypeEnum, TypeMixin, TypeRegister and SubcatalogTypeRegister.
+"""TypeEnum, TypeMixin and TypeRegister.
 
 :class:`TypeEnum` is a superclass for enumeration classes that need to create a mapping with class.
 
@@ -12,9 +12,6 @@
 :class:`TypeRegister` is a decorator, which is used for registering
 :class:`TypeMixin` to :class:`TypeEnum`.
 
-:class:`SubcatalogTypeRegister` is a decorator, which is used for registering
-:class:`TypeMixin` to :class:`TypeEnum`.
-
 """
 
 from enum import Enum
@@ -29,7 +26,6 @@ class TypeEnum(Enum):
     """
 
     __registry__: Dict["TypeEnum", Type[Any]] = {}
-    __subcatalog_registry__: Dict["TypeEnum", Type[Any]]
 
     def __init_subclass__(cls) -> None:
         cls.__registry__ = {}
@@ -95,29 +91,3 @@ class TypeRegister(Generic[_T]):  # pylint: disable=too-few-public-methods
         class_._enum = self._enum
         self._enum.__registry__[self._enum] = class_
         return class_
-
-
-class SubcatalogTypeRegister(Generic[_T]):  # pylint: disable=too-few-public-methods
-    """SubcatalogTypeRegister is a decorator, which is used for registering TypeMixin to TypeEnum.
-
-    Arguments:
-        enum: The corresponding :class:`TypeEnum` of the :class:`TypeMixin`.
-
-    """
-
-    def __init__(self, enum: _T) -> None:
-        self._enum = enum
-
-    def __call__(self, class_: Type[_S]) -> Type[_S]:
-        """Call the SubcatalogTypeRegister as a function.
-
-        Arguments:
-            class_: The :class:`TypeEnum` of the :class:`TypeMixin` to be registered.
-
-        Returns:
-            The :class:`TypeEnum` of the :class:`TypeMixin`.
-
-        """
-        class_._enum = self._enum
-        self._enum.__subcatalog_registry__[self._enum] = class_
-        return class_
